#
# spec file for package jfreechart
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jfreechart
Version:        1.5.4
Release:        1.4
Summary:        Java chart library
License:        LGPL-2.1-or-later
URL:            https://www.jfree.org/%{name}/
Source0:        https://github.com/jfree/%{name}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(javax.servlet:javax.servlet-api) >= 2.5
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.jfree:jcommon) >= 1.0.23
BuildRequires:  mvn(org.sonatype.oss:oss-parent:pom:)
BuildArch:      noarch

%description
JFreeChart is a comprehensive free chart library for the Java™ platform that
can be used on the client-side (JavaFX and Swing) or the server side, with
export to multiple formats including SVG, PNG and PDF.

%package javadoc
Summary:        Javadocs for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       jpackage-utils

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q

MVN_BUNDLE_PLUGIN_EXTRA_XML="<extensions>true</extensions>
        <configuration>
          <instructions>
            <Bundle-SymbolicName>org.jfree.jfreechart</Bundle-SymbolicName>
            <Bundle-Vendor>Fedora Project</Bundle-Vendor>
            <Bundle-Version>%{version}</Bundle-Version>
            <!-- Do not autogenerate uses clauses in Manifests -->
            <Import-Package>
              !javax.servlet,
              !javax.servlet.http,
              *
            </Import-Package>
            <_nouses>true</_nouses>
          </instructions>
        </configuration>"
%pom_remove_plugin :maven-gpg-plugin
%pom_remove_plugin :nexus-staging-maven-plugin
%pom_remove_plugin :cobertura-maven-plugin
%pom_remove_plugin :maven-jxr-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_change_dep javax.servlet:servlet-api: javax.servlet:javax.servlet-api:

%pom_add_plugin org.apache.felix:maven-bundle-plugin . "$MVN_BUNDLE_PLUGIN_EXTRA_XML"
# Change to packaging type bundle so as to be able to use it
# as an OSGi bundle.
%pom_xpath_set "pom:packaging" "bundle"

%{mvn_file} : %{name}

%build
%{mvn_build} -f  -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license licence-LGPL.txt
%doc README.md

%files javadoc -f .mfiles-javadoc
%license licence-LGPL.txt

%changelog
* Fri Oct  6 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to version 1.5.4
  * Version 1.5.4 (8 January 2023)
    + add new methods to access maps for datasets, renderers and
    axes in plots (#201);
    + add option to truncate item labels and compute contrast
    colors (PR #225)
    + add new annotations (PR #226)
    + add new panel for background rendering of charts (PR #233)
    + fix tick label font for LogAxis with number format override
    (#98);
    + added valueVisible flag to MeterPlot (#231);
    + added get/setWebFillAlpha() methods to SpiderWebPlot (#279)
    + add argument checks for annotations (#223);
    + removed JFreeChartResources.java file (#239)
  * Version 1.5.3 (21 February 2021)
    + add new FlowPlot class for drawing Sankey charts;
    + throw exception in DefaultPieDataset for invalid index
    (#212);
    + fix isJFreeSVGAvailable() method (bug #207);
    + replaced some usages of ObjectUtils with the JDK Objects
    class;
    + remove unused URLUtilities class;
    + removed @since 1.0.x Javadoc tags since these do not provide
    useful information anymore.
  * Version 1.5.2 (31 December 2020)
    + observe series visibility flag in ClusteredXYBarRenderer
    (#89);
    + apply rendering hints to overlays (#187);
    + don't draw disabled outlines on crosshair labels (#189);
    + observe axis visibility flag in PeriodAxis (#198);
    + ensure label offsets are used in CrosshairOverlay (#190);
    + remove alpha channel from copy-to-clipboard (#182);
    + set flag in XML parser to avoid XML eXternal Entity injection
    (XXE) (#130);
    + update French translations (#186);
    + fix "Save_as" entries in localisation files (#184);
    + add flags for visibility of outliers in BoxAndWhiskerRenderer
    (#79);
    + deprecated PiePlot3D and related methods, for 3D pie charts,
    use Orson Charts (https://github.com/jfree/orson-charts).
  * Version 1.5.1 (29 October 2020)
    + add DeviationStepRenderer (PR #173)
    + modify buffer in ChartPanel to handle high DPI displays (bug
    [#170]);
    + fix for exception on extreme zoom on NumberAxis (bug #64);
    + fix for LayeredBarRenderer (bug #169);
    + add Catalan translations (PR #117);
    + add automatic module name org.jfree.jfreechart;
    + migrate to JUnit 5;
    + raise minimum requirement to Java 8 or later.
  * Version 1.5.0
- Use source tarball from GitHub.
- Remove patch:
  * build_swt_encoding_fix.patch
    + Not needed anymore
- Remove obsolete stuff from the spec file
- Update package description
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Fri Feb 28 2020 Fridrich Strba <fstrba@suse.com>
- Initial packaging of jfreechart 1.0.19
